package com.songhua.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.songhua.common.annotation.Log;
import com.songhua.common.core.controller.BaseController;
import com.songhua.common.core.domain.AjaxResult;
import com.songhua.common.enums.BusinessType;
import com.songhua.system.domain.ScenicAreaManagement;
import com.songhua.system.service.IScenicAreaManagementService;
import com.songhua.common.utils.poi.ExcelUtil;
import com.songhua.common.core.page.TableDataInfo;


/**
 * 景区管理Controller
 *
 * @author lc
 * @date 2024-07-04
 */
@RestController
@RequestMapping("/system/management")
public class ScenicAreaManagementController extends BaseController
{
    @Autowired
    private IScenicAreaManagementService scenicAreaManagementService;

    /**
     * 查询景区管理列表
     */
    @GetMapping("/list")
    public TableDataInfo list(ScenicAreaManagement scenicAreaManagement)
    {
        startPage();
        List<ScenicAreaManagement> list = scenicAreaManagementService.selectScenicAreaManagementList(scenicAreaManagement);
        return getDataTable(list);
    }

    /**
     * 手机端查询景区管理列表
     */
    @GetMapping("/appList")
    public AjaxResult appList(ScenicAreaManagement scenicAreaManagement) {
        return success(scenicAreaManagementService.selectScenicAreaManagementList(scenicAreaManagement));
    }

    /**
     * 导出景区管理列表
     */
    @Log(title = "景区管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ScenicAreaManagement scenicAreaManagement)
    {
        List<ScenicAreaManagement> list = scenicAreaManagementService.selectScenicAreaManagementList(scenicAreaManagement);
        ExcelUtil<ScenicAreaManagement> util = new ExcelUtil<>(ScenicAreaManagement.class);
        util.exportExcel(response, list, "景区管理数据");
    }

    /**
     * 获取景区管理详细信息
     */
    @GetMapping("/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(scenicAreaManagementService.selectScenicAreaManagementById(id));
    }

    /**
     * 新增景区管理
     */
    @Log(title = "景区管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ScenicAreaManagement scenicAreaManagement)
    {
        return toAjax(scenicAreaManagementService.insertScenicAreaManagement(scenicAreaManagement));
    }

    /**
     * 修改景区管理
     */
    @Log(title = "景区管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ScenicAreaManagement scenicAreaManagement)
    {
        return toAjax(scenicAreaManagementService.updateScenicAreaManagement(scenicAreaManagement));
    }

    /**
     * 删除景区管理
     */
    @Log(title = "景区管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(scenicAreaManagementService.deleteScenicAreaManagementByIds(ids));
    }
}